package com.example.sampleproject;

import jp.co.nsw.baassdk.PushIntentService;
import android.content.Intent;
import android.os.Bundle;
import android.util.Log;

/**
 * PushIntentServiceを継承したクラスを作成。
 * onPushReceived()をオーバーライドすることで、カスタム動作を実施する。
 */
public class CustomPushIntentService extends PushIntentService {

    @Override
    protected boolean onPushReceived(Intent intent) {
        boolean ret = false;
        Bundle extras = intent.getExtras();
        
        /******************************************************************************************
         * プッシュ受信時のカスタム動作
         * 
         * ポスモバのプッシュ配信メッセージ画面の「オプション-JSONデータ」に以下のように入力し、
         * 動作を切り分けることが可能です。
         * 
         * ・アクション1を実行するためのプッシュ配信を実施する場合
         *   {"data" : {"no_display_action" : "action1"}}
         * 
         * ・アクション2を実行するためのプッシュ配信を実施する場合
         *   {"data" : {"no_display_action" : "action2"}}
         ******************************************************************************************/
        String action = extras.getString("no_display_action");
        if (action != null) {
            if (action.equals("action1")) {
                // アクション1の処理を実施
                Log.i("Sample", "アクション1を受信しました。");
                
                
                
                // trueを返し、SDK自動処理を停止する
                ret = true;
            } else if (action.equals("action2")) {
                // アクション2の処理を実施
                Log.i("Sample", "アクション2を受信しました。");
                
                
                
                // trueを返し、SDK自動処理を停止する
                ret = true;
            }
        }

        return ret;
    }
}
